/***************************************************************************
 *   Copyright (C) 2008 by Marcel Hasler                                   *
 *   mahasler@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "configurationdialog.h"
#include "defs.h"

#include <qslider.h>
#include <qspinbox.h>

#include <kcolorbutton.h>
#include <kconfig.h>
#include <kglobal.h>

ConfigurationDialog::ConfigurationDialog(QWidget* parent, const char* name, bool modal, WFlags)
: KVO_ConfigLayout(parent, name, modal,Qt::WDestructiveClose)
{
}


ConfigurationDialog::~ConfigurationDialog()
{
}


void ConfigurationDialog::show()
{
	this->setValues();
	this->QWidget::show();
}


void ConfigurationDialog::slotClose()
{
	emit closed();
	close();
}


void ConfigurationDialog::setValues()
{
	KConfig *config = KGlobal::config();
	config->setGroup("Appearance");

	m_sliderHPos->setValue(config->readNumEntry("HPos"));
	m_spinboxHPos->setValue(config->readNumEntry("HPos"));

	m_sliderVPos->setValue(config->readNumEntry("VPos"));
	m_spinboxVPos->setValue(config->readNumEntry("VPos"));

	m_sliderSize->setValue(config->readNumEntry("Size"));
	m_spinboxSize->setValue(config->readNumEntry("Size"));

	m_spinboxTimeout->setValue(config->readNumEntry("Timeout"));

	m_buttonBackColor->setColor(config->readColorEntry("BackColor"));
	m_buttonFrontColor->setColor(config->readColorEntry("FrontColor"));
}


void ConfigurationDialog::hPosValueChanged(int value)
{
	m_sliderHPos->setValue(value);
	m_spinboxHPos->setValue(value);
}


void ConfigurationDialog::vPosValueChanged(int value)
{
	m_sliderVPos->setValue(value);
	m_spinboxVPos->setValue(value);
}


void ConfigurationDialog::sizeValueChanged(int value)
{
	m_sliderSize->setValue(value);
	m_spinboxSize->setValue(value);
}


void ConfigurationDialog::slotSave()
{
	KConfig *config = KGlobal::config();
	config->setGroup("Appearance");

	config->writeEntry("HPos", m_spinboxHPos->value());
	config->writeEntry("VPos", m_spinboxVPos->value());
	config->writeEntry("Size", m_spinboxSize->value());
	config->writeEntry("Timeout", m_spinboxTimeout->value());

	config->writeEntry("BackColor", m_buttonBackColor->color());
	config->writeEntry("FrontColor", m_buttonFrontColor->color());

	config->sync();
	emit changed();
}

void ConfigurationDialog::buttonDefaultsClicked()
{
	m_sliderHPos->setValue(OSD_DEFAULT_HPOS);
	m_spinboxHPos->setValue(OSD_DEFAULT_HPOS);

	m_sliderVPos->setValue(OSD_DEFAULT_VPOS);
	m_spinboxVPos->setValue(OSD_DEFAULT_VPOS);

	m_sliderSize->setValue(OSD_DEFAULT_SIZE);
	m_spinboxSize->setValue(OSD_DEFAULT_SIZE);

	m_spinboxTimeout->setValue(OSD_DEFAULT_TIMEOUT);

	m_buttonBackColor->setColor(OSD_DEFAULT_BACK_COLOR);
	m_buttonFrontColor->setColor(OSD_DEFAULT_FRONT_COLOR);
}

void ConfigurationDialog::buttonAboutClicked()
{
	emit aboutClicked();
}


#include "configurationdialog.moc"

