/***************************************************************************
 *   Copyright (C) 2008 by Marcel Hasler                                   *
 *   mahasler@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "kvolumeosd.h"
#include "defs.h"

#include <qlabel.h>

#include <klocale.h>
#include <kglobalaccel.h>
#include <kcmdlineargs.h>
#include <kconfig.h>
#include <kglobal.h>

#include <iostream>
using namespace std;

KVolumeOSD::KVolumeOSD()
	: KUniqueApplication()
{
	this->initializeConfiguration();

	m_globalAccel = new KGlobalAccel(this);
	m_globalAccel->insert("RaiseVolume", QString::null, QString::null, KShortcut(Qt::Key_VolumeUp), KShortcut(Qt::Key_VolumeUp), this, SLOT(slotVolumeUp()));
	m_globalAccel->insert("LowerVolume", QString::null, QString::null, KShortcut(Qt::Key_VolumeDown), KShortcut(Qt::Key_VolumeDown), this, SLOT(slotVolumeDown()));
	m_globalAccel->insert("MuteVolume", QString::null, QString::null, KShortcut(Qt::Key_VolumeMute), KShortcut(Qt::Key_VolumeMute), this, SLOT(slotVolumeMute()));
	m_globalAccel->updateConnections();

	m_mixer = new Mixer();
	m_osd = new OSD();
	m_configWindow = 0;
	m_aboutWindow = new KAboutApplication(0, "aboutWindow", true);
}

KVolumeOSD::~KVolumeOSD()
{
}


void KVolumeOSD::initializeConfiguration()
{
	// Ensure that all entries have values
	KConfig *config = KGlobal::config();
	config->setGroup("Appearance");

	if (config->readNumEntry("HPos", -1) == -1)
		config->writeEntry("HPos", OSD_DEFAULT_HPOS);
	if (config->readNumEntry("VPos", -1) == -1)
		config->writeEntry("VPos", OSD_DEFAULT_VPOS);

	if (config->readNumEntry("Size", -1) == -1)
		config->writeEntry("Size", OSD_DEFAULT_SIZE);

	if (config->readNumEntry("Timeout", -1) == -1)
		config->writeEntry("Timeout", OSD_DEFAULT_TIMEOUT);

	if (!config->readColorEntry("BackColor").isValid())
		config->writeEntry("BackColor", OSD_DEFAULT_BACK_COLOR);
	if (!config->readColorEntry("FrontColor").isValid())
		config->writeEntry("FrontColor", OSD_DEFAULT_FRONT_COLOR);

	config->sync();
}


int KVolumeOSD::newInstance()
{
	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

	if (args->isSet("configure"))
		this->slotShowConfigWindow();
	else if (args->isSet("quit"))
		this->quit();

	args->clear();
	return 0;
}


void KVolumeOSD::slotShowConfigWindow()
{
	m_configWindow = new ConfigurationDialog();
	m_configWindow->show();
	connect(m_configWindow, SIGNAL(changed()), m_osd, SLOT(slotUpdate()));
	connect(m_configWindow, SIGNAL(aboutClicked()), this, SLOT(slotShowAboutWindow()));
}


void KVolumeOSD::slotVolumeUp()
{
	m_mixer->setMute(false);
	unsigned int volume = m_mixer->volumeUp();
	m_osd->show(volume, VolUp);
}


void KVolumeOSD::slotVolumeDown()
{
	m_mixer->setMute(false);
	unsigned int volume = m_mixer->volumeDown();
	m_osd->show(volume, VolDown);
}


void KVolumeOSD::slotVolumeMute()
{
	bool mute = m_mixer->toggleMute();
	unsigned int volume = m_mixer->getVolume();

	if (mute)
		m_osd->show(volume, Mute);
	else
		m_osd->show(volume, Unmute);

}


void KVolumeOSD::slotShowAboutWindow()
{
	m_aboutWindow->show();
}


void KVolumeOSD::quit()
{
	cout << "Thanks for using KVolumeOSD!" << endl;
	exit(0);
}

#include "kvolumeosd.moc"
