/***************************************************************************
 *   Copyright (C) 2008 by Marcel Hasler                                   *
 *   mahasler@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "mixer.h"

#include <kuniqueapplication.h>
#include <dcopclient.h>

#include <iostream>
using namespace std;

Mixer::Mixer()
{
	m_dcopClient = KUniqueApplication::dcopClient();
}


Mixer::~Mixer()
{
	delete m_dcopClient;
}


unsigned int Mixer::getVolume()
{
	QByteArray data, replyData;
	QCString replyType;
	unsigned int volume;

	if (!m_dcopClient->call("kmix", "Mixer0", "masterVolume()", data, replyType, replyData))
	{
		cout << "Error: Couldn't retrieve volume from KMix!" << endl;
		return 0;
	}

	QDataStream reply(replyData, IO_ReadOnly);
	reply >> volume;
	return volume;
}


bool Mixer::isMuted()
{
	QByteArray data, replyData;
	QCString replyType;
	bool mute;

	if (!m_dcopClient->call("kmix", "Mixer0", "masterMute()", data, replyType, replyData))
	{
		cout << "Error: Couldn't retrieve state from KMix!" << endl;
		return true;
	}

	QDataStream reply(replyData, IO_ReadOnly);
	reply >> mute;
	return mute;
}


unsigned int Mixer::volumeUp()
{
	QByteArray data, replyData;
	QCString replyType;
	QDataStream arg(data, IO_WriteOnly);
	arg << 0;
	unsigned int volume;

	if (!m_dcopClient->call("kmix", "Mixer0", "increaseVolume(int)", data, replyType, replyData))
		cout << "Error: Couldn't set volume!" << endl;

	if (!m_dcopClient->call("kmix", "Mixer0", "masterVolume()", data, replyType, replyData))
	{
		cout << "Error: Couldn't retrieve volume from KMix!" << endl;
		return 0;
	}

	QDataStream reply(replyData, IO_ReadOnly);
	reply >> volume;
	return volume;
}


unsigned int Mixer::volumeDown()
{
	QByteArray data, replyData;
	QCString replyType;
	QDataStream arg(data, IO_WriteOnly);
	arg << 0;
	unsigned int volume;

	if (!m_dcopClient->call("kmix", "Mixer0", "decreaseVolume(int)", data, replyType, replyData))
		cout << "Error: Couldn't set volume!" << endl;

	if (!m_dcopClient->call("kmix", "Mixer0", "masterVolume()", data, replyType, replyData))
	{
		cout << "Error: Couldn't retrieve volume from KMix!" << endl;
		return 0;
	}

	QDataStream reply(replyData, IO_ReadOnly);
	reply >> volume;
	return volume;
}


bool Mixer::toggleMute()
{
	QByteArray data, replyData;
	QCString replyType;
	bool mute;

	if (!m_dcopClient->call("kmix", "Mixer0", "toggleMasterMute()", data, replyType, replyData))
		cout << "Error: Couldn't toggle mute!" << endl;

	if (!m_dcopClient->call("kmix", "Mixer0", "masterMute()", data, replyType, replyData))
	{
		cout << "Error: Couldn't retrieve state from KMix!" << endl;
		return true;
	}

	QDataStream reply(replyData, IO_ReadOnly);
	reply >> mute;
	return mute;
}


void Mixer::setMute(bool mute)
{
	QByteArray data, replyData;
	QCString replyType;
	QDataStream arg(data, IO_WriteOnly);
	arg << mute;

	if (!m_dcopClient->call("kmix", "Mixer0", "setMasterMute(bool)", data, replyType, replyData))
		cout << "Error: Couldn't set mute!" << endl;
}




